# -*- coding: utf-8 -*-
from django.db import models

from . import forms


class ColorField(models.CharField):
    description = ("A simple field to store a color's RGB values "
                   "in triple HEX format")

    def __init__(self, *args, **kwargs):
        kwargs['max_length'] = 6
        super().__init__(*args, **kwargs)

    def deconstruct(self):
        name, path, args, kwargs = super().deconstruct()
        del kwargs['max_length']
        return name, path, args, kwargs

    def formfield(self, **kwargs):
        kwargs['form_class'] = forms.ColorField
        return super().formfield(**kwargs)



# -*- coding: utf-8 -*-
import re

from django import forms
from django.core.exceptions import ValidationError
from django.template.loader import render_to_string

from .widgets import ColorInputWidget


class ColorField(forms.CharField):
    widget = ColorInputWidget()

    def clean(self, value):
        hex_value = value.lstrip('#')
        rgb_pattern = re.compile('[0-9a-fA-F]{6}')
        if not rgb_pattern.search(hex_value):
            raise ValidationError('Invalid RGB value: {}'.format(value))
        return hex_value

    def prepare_value(self, value):
        return '#' + value



import setuptools

with open('README.rst', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='django-colorinput',
    version='0.1',
    author='Gabriel Niebler',
    author_email='gabriel.niebler@gmail.com',
    description='Color fields for Django models and forms '
                'using HTML5 native color type input elements',
    long_description=long_description,
    long_description_content_type='text/x-rst',
    url='https://github.com/der-gabe/django-colorinput',
    packages=setuptools.find_packages(),
    classifiers=[
        'Framework :: Django',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
    ],
    python_requires='>=3.6',
)
